import { httpApi } from '../../request/httpApi'


export default {
    //获取当前合同段下的日志类型
    async queryLogList(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/queryCurrentContractLogList',
            method: 'get',
            params: form,
        }, msg)
    },
    //获取当前日志类型的填报人
    async queryFillUser(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/queryFillUser',
            method: 'get',
            params: form,
        }, msg)
    },
    //施工日志分页
    async constructionLogPage(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/constructionLogPage',
            method: 'post',
            data: form,
        }, msg)
    },
    //批量废除
    async batchAbolish(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/batchAbolish',
            method: 'post',
            params: form,
        }, msg)
    },
    //获取合同段当前日志节点下的填报日期记录
    async getSubmitLogDateList(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/getSubmitLogDateList',
            method: 'post',
            params: form,
        }, msg)
    },
    //清表生成html
    // async getExcelHtml(form, msg = true) {
    //     return httpApi({
    //         url: '/api/blade-manager/exceltab/get-excel-html',
    //         method: 'get',
    //         params: form
    //     }, msg);
    // },
    async getExcelHtml(form, msg = true) {
        return httpApi({
            url: '/api/blade-manager/exceltab/get-excel-html-two',
            method: 'get',
            params: form,
        }, msg)
    },
    //获取表单数据
    async getBussDataInfo(form, msg = true) {
        return httpApi({
            url: '/api/blade-manager/exceltab/get-the-log-business-data',
            method: 'get',
            params: form,
        }, msg)
    },
    //获取表单数据
    async getTheLogBusinessData(form, msg = true) {
        return httpApi({
            url: '/api/blade-manager/exceltab/get-the-log-business-data',
            method: 'get',
            params: form,
        }, msg)
    },
    //填报页面数据保存
    async saveExcelBussData(form, msg = true) {
        return httpApi({
            url: '/api/blade-manager/exceltab/save_log_first_buss_data',
            method: 'post',
            data: form,
        }, msg)
    },
    //单表pdf预览
    async getBussPdfInfo(form, msg = true) {
        return httpApi({
            url: '/api/blade-manager/exceltab/get-the-log-pdfInfo',
            method: 'get',
            params: form,
        }, msg)
    },
    //获取当前日志资料关联的工序节点信息
    async queryCurrentLogSelectProcessList(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/queryCurrentLogSelectProcessList',
            method: 'post',
            params: form,
        }, msg)
    },
    //获取当前资料的任务状态
    async checkTheLogTaskStatus(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/checkTheLogTaskStatus',
            method: 'get',
            params: form,
        }, msg)
    },
    //预览、打印
    async theLogPreviewAndPrint(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/theLogPreviewAndPrint',
            method: 'post',
            data: form,
        }, msg)
    },
    //废除
    async theLogOneAbolish(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/oneAbolish',
            method: 'get',
            params: form,
        }, msg)
    },
    //删除
    async theLogRemoveByIds(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/removeByIds',
            method: 'post',
            data: form,
        }, msg)
    },
    //获取当前合同段下本日志节点的填报资料日期树
    async queryReportLogTimeTree(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/queryReportLogTimeTree',
            method: 'get',
            params: form,
        }, msg)
    },
    //获取填报记录
    async queryLogTimeTreeList(form, msg = true) {
        return httpApi({
            url: '/api/blade-business/contractLog/queryLogList',
            method: 'get',
            params: form,
        }, msg)
    },
    //复制任意时间
    async copyTheLogBusinessData(form, msg = true) {
        return httpApi({
            url: '/api/blade-manager/exceltab/copy-the-log-business-data',
            method: 'get',
            params: form,
        }, msg)
    },

    //1、删除施工日志对应的表数据记录信息接口POST：/api/blade-manager/exceltab/removeLogTab
    async removeLogTab(form, msg = true) {
        return httpApi({
            url: '/api/blade-manager/exceltab/removeLogTab',
            method: 'post',
            params: form,
        }, msg)
    },
}
